<?php
/**
*
* acp_board.php [Lithuanian]
*
* @package language
* @version $Id: $
* @copyright (c) 2012 phpBB Group
* @author 2012-01-04 - Vilius Šumskas
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'Čia galite nustatyti pagrindinius diskusijų lentos nustatymus, nurodyti jos pavadinimą ir trumpą aprašymą, bei nustatyti standartinę laiko juostą bei kalbą.',
	'CUSTOM_DATEFORMAT'	=> 'Individualus…',
	'DEFAULT_DATE_FORMAT'	=> 'Datos formatas',
	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Naudojama sintaksė identiška PHP funkcijos <code>date</code> sintaksei.',
	'DEFAULT_LANGUAGE'	=> 'Pagrindinė kalba',
	'DEFAULT_STYLE'	=> 'Standartinis stilius',
	'DISABLE_BOARD'	=> 'Išjungti diskusijų lentą',
	'DISABLE_BOARD_EXPLAIN'	=> 'Šiuo nustatymu galite laikinai išjungti diskusijų lentą. Jeigu pageidaujate, galite įrašyti trumpą (iki 255 simbolių) žinutę.',
	'OVERRIDE_STYLE'	=> 'Išjungti vartotojų stilius',
	'OVERRIDE_STYLE_EXPLAIN'	=> 'Pakeičia vartotojų stilius standartiniu stiliumi.',
	'SITE_DESC'	=> 'Diskusijų lentos apibūdinimas',
	'SITE_NAME'	=> 'Diskusijų lentos pavadinimas',
	'SYSTEM_DST'	=> 'Įjungti vasaros laiką/<abbr title="Daylight Saving Time">DST</abbr>',
	'SYSTEM_TIMEZONE'	=> 'Svečių laiko juosta',
	'SYSTEM_TIMEZONE_EXPLAIN'	=> 'Laiko juosta, kuri bus naudojama rodant laiką neprisijungusiems dalyviams (svečiams, robotams). Prisijungę dalyviai pasirenka savo laiko juostą registracijos metu ir gali ją bet kada pasikeisti savo varotojo valdymo pulte.',
	'WARNINGS_EXPIRE'	=> 'Perspėjimo trukmė',
	'WARNINGS_EXPIRE_EXPLAIN'	=> 'Dienų skaičius, kai perspėjimas bus automatiškai ištrintas iš vartotojo įrašo. Jeigu norite, kad perspėjimai būtų nuolatiniai, įrašykite 0.',
	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'Čia galite įjungti/išjungti kai kurias diskusijų lentos galimybes.',
	'ALLOW_ATTACHMENTS'	=> 'Leisti prikabinti failus',
	'ALLOW_BIRTHDAYS'	=> 'Įjungti gimtadienius',
	'ALLOW_BIRTHDAYS_EXPLAIN'	=> 'Įjungti gimtadienių įrašymą ir rodymą aprašuose. Gimtadienių rodymas pirmame diskusijų puslapyje yra valdomas per atskirus apkrovimo nustatymus.',
	'ALLOW_BOOKMARKS'	=> 'Leisti žymėti temas',
	'ALLOW_BOOKMARKS_EXPLAIN'	=> 'Vartotojas gali saugoti asmenines žymes.',
	'ALLOW_BBCODE'	=> 'Leisti BBKodą',
	'ALLOW_FORUM_NOTIFY'	=> 'Leisti prenumeruoti forumus',
	'ALLOW_NAME_CHANGE'	=> 'Leisti keisti vartotojo vardą',
	'ALLOW_NO_CENSORS'	=> 'Leisti išjungti cenzūrą',
	'ALLOW_NO_CENSORS_EXPLAIN'	=> 'Vartotojai gali pasirinkti, ar išjungti automatinę pranešimų ir asmeninių žinučių cenzūrą.',
	'ALLOW_PM_ATTACHMENTS'	=> 'Leisti prikabinti failus asmeninėse žinutėse',
	'ALLOW_PM_REPORT'	=> 'Leisti vartotojams raportuoti apie asmenines žinutes',
	'ALLOW_PM_REPORT_EXPLAIN'	=> 'Jeigu šis nustatymas įjungtas, vartotojai turi galimybę raportuoti apie asmeninę žinutę, kurią jie gavo, diskusijų moderatoriams. Šios asmeninės žinutės bus matomos moderatoriaus valdymo pulte.',
	'ALLOW_QUICK_REPLY'	=> 'Leisti greituosius atsakymus',
	'ALLOW_QUICK_REPLY_EXPLAIN'	=> 'Šis nustatymas leidžia išjungti greituosius atsakymus visoje lentoje. Jeigu jis įjungtas, atitinkamuose forumuose turi būti priskirta greitųjų atsakymų teisė.',
	'ALLOW_QUICK_REPLY_BUTTON'	=> 'Išsaugoti ir įjungti greituosius atsakymus visuose forumuose',
	'ALLOW_SIG'	=> 'Leisti parašus',
	'ALLOW_SIG_BBCODE'	=> 'Leisti BBKodą vartotojų parašuose',
	'ALLOW_SIG_FLASH'	=> 'Leisti naudoti <code>[FLASH]</code> BBKodo žymes vartotojų parašuose',
	'ALLOW_SIG_IMG'	=> 'Leisti naudoti <code>[IMG]</code> BBKodo žymes vartotojų parašuose',
	'ALLOW_SIG_LINKS'	=> 'Leisti naudoti nuorodas vartotojų parašuose',
	'ALLOW_SIG_LINKS_EXPLAIN'	=> 'Jeigu šis nustatymas išjungtas <code>[URL]</code> BBKodo žymės bei automatiniai URL adresai bus išjungti.',
	'ALLOW_SIG_SMILIES'	=> 'Leisti naudoti šypsenėles vartotojų parašuose',
	'ALLOW_SMILIES'	=> 'Leisti šypsenėles',
	'ALLOW_TOPIC_NOTIFY'	=> 'Leisti prenumeruoti temas',
	'BOARD_PM'	=> 'Asmeninis susirašinėjimas',
	'BOARD_PM_EXPLAIN'	=> 'Įjungti asmeninį susirašinėjimą visiems vartotojams.',
	'ACP_AVATAR_SETTINGS_EXPLAIN'	=> 'Avatarai dažniausiai yra maži unikalūs paveikslėliai, kurie kaip nors susiję su vartotoju. Priklausomai nuo naudojamo stiliaus, avatarai rodomi temoje po vartotojo vardu. Čia galite nustatyti kaip vartotojai nurodys savo avatarus. Atsiminkite, jog norėdami laikyti avatarus savo serveryje turėsite sukurti žemiau nurodytą katalogą ir įsitikinti kad jūsų serveris gali į jį rašyti. Tai pat įsidėmėkite, kad failo dydžio ribojimas galioja tik vietiniams avatarams, jis negalioja nutolusiems paveikslėliams.',
	'ALLOW_AVATARS'	=> 'Įjungti avatarus',
	'ALLOW_AVATARS_EXPLAIN'	=> 'Leisti naudoti avatarus;<br />Jeigu išjungsite pačius avatarus arba tam tikrą avatarų tipą, jie nebus rodomi diskusijų lentoje, tačiau vartotojai galės atsisiųsti savo avatarus per vartotojo valdymo pultą.',
	'ALLOW_LOCAL'	=> 'Įjungti avatarų galeriją',
	'ALLOW_REMOTE'	=> 'Įjungti nutolusius avatarus',
	'ALLOW_REMOTE_EXPLAIN'	=> 'Šie avatarai saugomi nutolusiuose puslapiuose.',
	'ALLOW_REMOTE_UPLOAD'	=> 'Įjungti nutolusių avatarų atsiuntimą',
	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'Leisti atsiųsti avatarus iš kito puslapio.',
	'ALLOW_UPLOAD'	=> 'Įjungti avatarų atsiuntimą',
	'AVATAR_GALLERY_PATH'	=> 'Kelias iki avatarų galerijos',
	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Kelias nuo jūsų phpBB pagrindinio katalogo iki avatarų galerijos, pvz.: <samp>images/avatars/gallery</samp>.',
	'AVATAR_STORAGE_PATH'	=> 'Avatarų saugojimo katalogas',
	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Jūsų pagrindinio phpBB katalogo pakatalogis, pvz.: <samp>images/avatars/upload</samp>.',
	'MAX_AVATAR_SIZE'	=> 'Maksimalios avataro dimensijos',
	'MAX_AVATAR_SIZE_EXPLAIN'	=> 'Plotis x aukštis pikseliais.',
	'MAX_FILESIZE'	=> 'Maksimalus avataro failo dydis',
	'MAX_FILESIZE_EXPLAIN'	=> 'Galioja vietiniams avatarams.',
	'MIN_AVATAR_SIZE'	=> 'Minimalios avataro dimensijos',
	'MIN_AVATAR_SIZE_EXPLAIN'	=> 'Plotis x aukštis pikseliais.',
	'ACP_MESSAGE_SETTINGS_EXPLAIN'	=> 'Čia galite keisti visus standartinius asmeninio susirašinėjimo nustatymus.',
	'ALLOW_BBCODE_PM'	=> 'Leisti BBKodą asmeninėse žinutėse',
	'ALLOW_FLASH_PM'	=> 'Leisti naudoti <code>[FLASH]</code> BBKodo žymę',
	'ALLOW_FLASH_PM_EXPLAIN'	=> 'Atsiminkite, kad ši galimybė priklauso ne tik nuo šio nustatymo, bet ir nuo vartotojo teisių.',
	'ALLOW_FORWARD_PM'	=> 'Leisti persiųsti asmenines žinutes',
	'ALLOW_IMG_PM'	=> 'Leisti naudoti <code>[IMG]</code> BBKodo žymę',
	'ALLOW_MASS_PM'	=> 'Leisti siųsti asmenines žinutes iš karto keliems vartotojams ar grupėms',
	'ALLOW_MASS_PM_EXPLAIN'	=> 'Asmeninių žinučių siuntimą kiekvienai grupei atskirai galima pakeisti grupių nustatymų puslapyje.',
	'ALLOW_PRINT_PM'	=> 'Leisti spausdinti asmenines žinutes',
	'ALLOW_QUOTE_PM'	=> 'Leisti cituoti asmenines žinutes',
	'ALLOW_SIG_PM'	=> 'Leisti įtraukti parašą į asmenines žinutes',
	'ALLOW_SMILIES_PM'	=> 'Leisti šypsenėles asmeninėse žinutėse',
	'BOXES_LIMIT'	=> 'Maksimalus asmeninių žinučių skaičius kataloge',
	'BOXES_LIMIT_EXPLAIN'	=> 'Kiekvienas vartotojas kiekviename savo kataloge gali turėti ne daugiau nei šis skaičius asmeninių žinučių. Jeigu norite riboti žinučių skaičiaus, įrašykite 0.',
	'BOXES_MAX'	=> 'Maksimalus asmeninių žinučių katalogų skaičius',
	'BOXES_MAX_EXPLAIN'	=> 'Standartiškai vartotojai gali sukurti tik tokį skaičių katalogų asmeninėms žinutėms.',
	'ENABLE_PM_ICONS'	=> 'Įjungti piktogramas asmeninėse žinutėse',
	'FULL_FOLDER_ACTION'	=> 'Standartinis veiksmas kai katalogas pilnas',
	'FULL_FOLDER_ACTION_EXPLAIN'	=> 'Šis veiksmas bus įvykdytas, kai vartotojo katalogas yra pilnas ir kai paties vartotojo nustatytas veiksmas yra netaikytinas. Tai netaikoma “Išsiųstų žinučių” katalogui, kuriame senos žinutės visada ištrinamos.',
	'HOLD_NEW_MESSAGES'	=> 'Naujos žinutės stovės eilėje',
	'PM_EDIT_TIME'	=> 'Riboti redagavimo laiką',
	'PM_EDIT_TIME_EXPLAIN'	=> 'Riboja laiką, per kurį galima redaguoti žinutę kol ji dar nepristatyta. Norėdami neriboti laiko, įrašykite 0.',
	'PM_MAX_RECIPIENTS'	=> 'Maksimalus gavėjų skaičius',
	'PM_MAX_RECIPIENTS_EXPLAIN'	=> 'Maksimalus asmeninės žinutės gavėjų skaičius. Jeigu nenorite riboti gavėjų skaičiaus, įrašykite 0. Šis parametras gali būti pakeistas kiekvienai grupei atskirai grupių nustatymų puslapyje.',
	'ACP_POST_SETTINGS_EXPLAIN'	=> 'Čia galite keisti visus standartinius pranešimų rašymo nustatymus.',
	'ALLOW_POST_LINKS'	=> 'Leisti nuorodas pranešimuose/asmeninėse žinutėse',
	'ALLOW_POST_LINKS_EXPLAIN'	=> 'Jeigu neleisite, <code>[URL]</code> BBKodo žymės ir automatiniai URL adresai bus išjungti.',
	'ALLOW_POST_FLASH'	=> 'Leisti naudoti <code>[FLASH]</code> BBKodo žymes pranešimuose',
	'ALLOW_POST_FLASH_EXPLAIN'	=> 'Jeigu neleisite, <code>[FLASH]</code> BBKodo žymės pranešimuose bus išjungtos. Priešingu atveju, kuris vartotojas gali naudoti <code>[FLASH]</code> BBKodo žymes, nuspręs teisių sistema.',
	'BUMP_INTERVAL'	=> 'Temų priminimo intervalas',
	'BUMP_INTERVAL_EXPLAIN'	=> 'Minučių, valandų arba dienų skaičius tarp paskutinio temos pranešimo ir galimybės priminti apie temą. Jeigu norite išjungti šią funkciją, įrašykite 0.',
	'CHAR_LIMIT'	=> 'Maksimalus pranešimo/žinutės simbolių skaičius',
	'CHAR_LIMIT_EXPLAIN'	=> 'Leidžiamas simbolių skaičius pranešime/žinutėje. Jeigu norite neriboti simbolių skaičiaus, įrašykite 0.',
	'DELETE_TIME'	=> 'Riboti trynimo laiką',
	'DELETE_TIME_EXPLAIN'	=> 'Riboja laiką, per kurį naujas pranešimas gali būti ištrintas. Jeigu norite išjungti šią funkciją, įrašykite 0.',
	'DISPLAY_LAST_EDITED'	=> 'Rodyti informaciją apie paskutinį redagavimą',
	'DISPLAY_LAST_EDITED_EXPLAIN'	=> 'Pasirinkite, ar rodyti kas paskutinis redagavo pranešimą.',
	'EDIT_TIME'	=> 'Riboti redagavimo laiką',
	'EDIT_TIME_EXPLAIN'	=> 'Riboja laiką, per kurį galima redaguoti naują pranešimą. Norėdami neriboti laiko, įrašykite 0.',
	'FLOOD_INTERVAL'	=> 'Srauto ribojimo intervalas',
	'FLOOD_INTERVAL_EXPLAIN'	=> 'Sekundžių skaičius, kurį turi laukti vartotojas prieš rašydamas kitą žinutę. Jeigu norite, kad vartotojams negaliotų šis parametras, nustatykite tai jų teisėse.',
	'HOT_THRESHOLD'	=> 'Žinučių populiariose temose',
	'HOT_THRESHOLD_EXPLAIN'	=> 'Žinučių kiekis, po kurio tema pažymima kaip populiari. Jeigu norite išjungti populiarių temų žymėjimą, įrašykite 0.',
	'MAX_POLL_OPTIONS'	=> 'Maksimalus apklausos atsakymų variantų skaičius',
	'MAX_POST_FONT_SIZE'	=> 'Maksimalus pranešimo šrifto dydis',
	'MAX_POST_FONT_SIZE_EXPLAIN'	=> 'Maksimalus leidžiamas pranešimo šrifto dydis. Jeigu norite neriboti šrifto dydžio, įrašykite 0.',
	'MAX_POST_IMG_HEIGHT'	=> 'Maksimalus pranešimo paveikslėlių aukštis',
	'MAX_POST_IMG_HEIGHT_EXPLAIN'	=> 'Maksimalus paveikslėlio/flash failo aukštis pranešime. Jeigu nenorite riboti šio dydžio, įrašykite 0.',
	'MAX_POST_IMG_WIDTH'	=> 'Maksimalus pranešimo paveikslėlių plotis',
	'MAX_POST_IMG_WIDTH_EXPLAIN'	=> 'Maksimalus paveikslėlio/flash failo plotis pranešime. Jeigu nenorite riboti šio dydžio, įrašykite 0.',
	'MAX_POST_URLS'	=> 'Maksimalus pranešimo nuorodų skaičius',
	'MAX_POST_URLS_EXPLAIN'	=> 'Maksimalus URL nuorodų skaičius pranešime. Jeigu nenorite riboti nuorodų skaičiaus, įrašykite 0.',
	'MIN_CHAR_LIMIT'	=> 'Minimalus pranešimo/žinutės simbolių skaičius',
	'MIN_CHAR_LIMIT_EXPLAIN'	=> 'Mažiausias simbolių skaičius, kurį vartotojas turi įrašyti į pranešimą/žinutę (ne mažiau nei 1).',
	'POSTING'	=> 'Rašymas',
	'POSTS_PER_PAGE'	=> 'Pranešimų viename puslapyje',
	'QUOTE_DEPTH_LIMIT'	=> 'Maksimalus citatų gylis',
	'QUOTE_DEPTH_LIMIT_EXPLAIN'	=> 'Maksimalus citatų gylis pranešime. Jeigu nenorite riboti citavimo gylio, įrašykite 0.',
	'SMILIES_LIMIT'	=> 'Maksimalus pranešimo šypsenėlių skaičius',
	'SMILIES_LIMIT_EXPLAIN'	=> 'Maksimalus šypsenėlių skaičius pranešime. Jeigu nenorite riboti šypsenėlių skaičiaus, įrašykite 0.',
	'SMILIES_PER_PAGE'	=> 'Šypsenėlių viename puslapyje',
	'TOPICS_PER_PAGE'	=> 'Temų viename puslapyje',
	'ACP_SIGNATURE_SETTINGS_EXPLAIN'	=> 'Čia galite keisti visus standartinius parašų nustatymus.',
	'MAX_SIG_FONT_SIZE'	=> 'Maksimalus parašo šrifto dydis',
	'MAX_SIG_FONT_SIZE_EXPLAIN'	=> 'Maksimalus leistinas parašo šrifto dydis. Jeigu nenorite riboti šrifto dydžio, įrašykite 0.',
	'MAX_SIG_IMG_HEIGHT'	=> 'Maksimalus parašo paveikslėlių aukštis',
	'MAX_SIG_IMG_HEIGHT_EXPLAIN'	=> 'Maksimalus paveikslėlio/flash failo aukštis vartotojo paraše. Jeigu nenorite riboti šio dydžio, įrašykite 0.',
	'MAX_SIG_IMG_WIDTH'	=> 'Maksimalus parašo paveikslėlių plotis',
	'MAX_SIG_IMG_WIDTH_EXPLAIN'	=> 'Maksimalus paveikslėlio/flash failo plotis vartotojo paraše. Jeigu nenorite riboti šio dydžio, įrašykite 0.',
	'MAX_SIG_LENGTH'	=> 'Maksimalus parašo ilgis',
	'MAX_SIG_LENGTH_EXPLAIN'	=> 'Maksimalus simbolių skaičius vartotojo paraše.',
	'MAX_SIG_SMILIES'	=> 'Maksimalus parašo šypsenėlių skaičius',
	'MAX_SIG_SMILIES_EXPLAIN'	=> 'Maksimalus šypsenėlių skaičius vartotojo paraše. Jeigu nenorite riboti šypsenėlių skaičiaus, įrašykite 0.',
	'MAX_SIG_URLS'	=> 'Maksimalus parašo nuorodų skaičius',
	'MAX_SIG_URLS_EXPLAIN'	=> 'Maksimalus nuorodų skaičius paraše. Jeigu nenorite riboti nuorodų skaičiaus, įrašykite 0.',
	'ACP_REGISTER_SETTINGS_EXPLAIN'	=> 'Čia galite aprašyti registracijos ir su vartotojų aprašais susijusius nustatymus.',
	'ACC_ACTIVATION'	=> 'Vartotojo vardo aktyvavimas',
	'ACC_ACTIVATION_EXPLAIN'	=> 'Šis parametras nurodo ar vartotojai iš karto gali prisijungti ar naujus vartotojų vardus jiems reikia patvirtinti. Taip pat čia galite visiškai išjungti registraciją. Jeigu norite, kad registracijas patvirtintų vartotojas arba administratorius, diskusijose turi būti įjungtos el. pašto funkcijos.',
	'NEW_MEMBER_POST_LIMIT'	=> 'Naujų dalyvių pranešimų riba',
	'NEW_MEMBER_POST_LIMIT_EXPLAIN'	=> 'Kol nauji dalyviai nepasiekia šio pranešimų skaičiaus, jie būna priskirti <em>Naujai užsiregistravusių vartotojų</em> grupei. Jūs galite naudoti šią grupę, jeigu norite neleisti tokiems vartotojams naudotis asmeninių žinučių sistema arba norėdami patogiau peržiūrėti jų pranešimus. <strong>Jeigu norite išjungti šią funkciją, įrašykite 0.</strong>',
	'NEW_MEMBER_GROUP_DEFAULT'	=> 'Nustatyti naujai užsiregistravusių vartotojų grupę pagrindine',
	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'Jeigu šis nustatymas įjungtas ir nustatyta naujų dalyvių pranešimų riba, naujai užsiregistravę vartotojai ne tik bus priskirti <em>Naujai užsiregistravusių vartotojų</em> grupei, bet ši grupė jiems bus pagrindinė. Tai gali būti naudinga, jeigu norite šiai grupei priskirti rangą ir/arba avatarą.',
	'ACC_ADMIN'	=> 'Administratorius',
	'ACC_DISABLE'	=> 'Išjungti registraciją',
	'ACC_NONE'	=> 'Aktyvuoti nereikia (iš karto suteikiamas leidimas)',
	'ACC_USER'	=> 'Vartotojas (el. paštu)',
	'ALLOW_EMAIL_REUSE'	=> 'Leisti el. pašto adresą panaudoti daugiau nei vieną kartą',
	'ALLOW_EMAIL_REUSE_EXPLAIN'	=> 'Skirtingi vartotojai galės registruotis su tuo pačiu el. pašto adresu.',
	'COPPA'	=> 'Apsaugos nuo vaikų (COPPA) nustatymai',
	'COPPA_FAX'	=> 'Fakso numeris',
	'COPPA_MAIL'	=> 'Pašto adresas',
	'COPPA_MAIL_EXPLAIN'	=> 'Paprasto pašto adresas, kur vaikų tėvai gali siųsti užpildytas registracijos anketas.',
	'ENABLE_COPPA'	=> 'Įjungti apsaugą nuo vaikų',
	'ENABLE_COPPA_EXPLAIN'	=> 'Šis parametras nurodo, kad vartotojai turi patvirtinti jog jiems yra 13 ar daugiau metų. Jeigu išjungsite, su šia funkcija susijusios grupės nebus rodomos.',
	'MAX_CHARS'	=> 'Maks.',
	'MIN_CHARS'	=> 'Min.',
	'NO_AUTH_PLUGIN'	=> 'Nerastas joks tinkamas autentifikavimo modulis.',
	'PASSWORD_LENGTH'	=> 'Slaptažodžio ilgis',
	'PASSWORD_LENGTH_EXPLAIN'	=> 'Minimalus ir maksimalus slaptažodžio simbolių skaičius.',
	'REG_LIMIT'	=> 'Bandymai užsiregistruoti',
	'REG_LIMIT_EXPLAIN'	=> 'Vartotojo bandymų užsiregistruoti ir įvykdyti užduotį įrodančią, jog jis nėra šiukšlių (spam) robotas skaičius, prieš tai kai sesija blokuojama.',
	'USERNAME_ALPHA_ONLY'	=> 'Tik skaičiai ir raidės',
	'USERNAME_ALPHA_SPACERS'	=> 'Skaičiai, raidės ir spec. simboliai',
	'USERNAME_ASCII'	=> 'ASCII (be tarptautinių simbolių)',
	'USERNAME_LETTER_NUM'	=> 'Bet kokios raidės ar skaičiai',
	'USERNAME_LETTER_NUM_SPACERS'	=> 'Bet kokios raidės, skaičiai ar spec. simboliai',
	'USERNAME_CHARS'	=> 'Riboti vartotojo vardo simbolius',
	'USERNAME_CHARS_ANY'	=> 'Bet kokie simboliai',
	'USERNAME_CHARS_EXPLAIN'	=> 'Vartotojo varde leisti naudoti tik tam tikrus simbolius. Specialieji simboliai yra: tarpas, -, +, _, [ ir ].',
	'USERNAME_LENGTH'	=> 'Vartotojo vardo ilgis',
	'USERNAME_LENGTH_EXPLAIN'	=> 'Minimalus ir maksimalus vartotojo vardo simbolių skaičius.',
	'ACP_FEED_MANAGEMENT'	=> 'Pagrindiniai sinchronizuojamų srautų nustatymai',
	'ACP_FEED_MANAGEMENT_EXPLAIN'	=> 'Šis modulis, apdorodamas pranešimų BBKodą, kuria įvairius ATOM srautus, kurie vėliau gali būti skaitomi išorinėmis programomis.',
	'ACP_FEED_GENERAL'	=> 'Pagrindiniai srautų nustatymai',
	'ACP_FEED_POST_BASED'	=> 'Pranešimų srautų nustatymai',
	'ACP_FEED_TOPIC_BASED'	=> 'Temų srautų nustatymai',
	'ACP_FEED_SETTINGS_OTHER'	=> 'Kiti srautai ir nustatymai',
	'ACP_FEED_ENABLE'	=> 'Įjungti srautus',
	'ACP_FEED_ENABLE_EXPLAIN'	=> 'Įjungia arba išjungia ATOM srautus visai diskusijų lentai.<br />Išjungus šį nustatymą, išjungiami visi srautai. Nustatymai esantys apačioje - nesvarbūs.',
	'ACP_FEED_LIMIT'	=> 'Elementų kiekis',
	'ACP_FEED_LIMIT_EXPLAIN'	=> 'Maksimalus elementų kiekis sraute.',
	'ACP_FEED_OVERALL'	=> 'Įjungti bendrą srautą',
	'ACP_FEED_OVERALL_EXPLAIN'	=> 'Bendras naujų pranešimų srautas.',
	'ACP_FEED_FORUM'	=> 'Įjungti srautus kiekvienam forumui',
	'ACP_FEED_FORUM_EXPLAIN'	=> 'Kiekvieno forumo ir jo subforumų naujausi pranešimai.',
	'ACP_FEED_TOPIC'	=> 'Įjungti srautus kiekvienai temai',
	'ACP_FEED_TOPIC_EXPLAIN'	=> 'Kiekvienos temos naujausi pranešimai.',
	'ACP_FEED_TOPICS_NEW'	=> 'Įjungti naujų temų srautą',
	'ACP_FEED_TOPICS_NEW_EXPLAIN'	=> 'Įjungia “Naujų temų” srautą, kuris parodo paskutines sukurtas temas, įskaitant pirmus jų pranešimus.',
	'ACP_FEED_TOPICS_ACTIVE'	=> 'Įjungti aktyvių temų srautą',
	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN'	=> 'Įungia “Aktyvių temų” srautą, kuris parodo paskutines aktyvias temas, įskaitant paskutinius jų pranešimus.',
	'ACP_FEED_NEWS'	=> 'Naujienų srautai',
	'ACP_FEED_NEWS_EXPLAIN'	=> 'Rodyti pirmus šių forumų pranešimus. Norėdami išjungti naujienų srautą nepasirinkite nei vieno forumo.<br />Laikydami <samp>CTRL</samp> ir paspaudę kairįjį pelės mygtuką galite pasirinkti daugiau nei vieną forumą.',
	'ACP_FEED_OVERALL_FORUMS'	=> 'Įjungti bendrą forumų srautą',
	'ACP_FEED_OVERALL_FORUMS_EXPLAIN'	=> 'Įjungia “Visų forumų” srautą, kuriame rodomas visų forumų sąrašas.',
	'ACP_FEED_HTTP_AUTH'	=> 'Leisti HTTP autentifikaciją',
	'ACP_FEED_HTTP_AUTH_EXPLAIN'	=> 'Įjungia HTTP autentifikaciją, kuri, prie srauto URL adreso pridėjus <samp>auth=http</samp>, leidžia vartotojams gauti turinį neprieinamą svečiams. Atsiminkite, kad kai kurie PHP diegimai reikalauja papildomų pakeitimų .htaccess faile. Instrukcijas rasite tame faile.',
	'ACP_FEED_ITEM_STATISTICS'	=> 'Elementų statistika',
	'ACP_FEED_ITEM_STATISTICS_EXPLAIN'	=> 'Po kiekvienu srauto elementu rodo individualią statistiką<br />(pvz. pranešimo autorių, datą ir laiką, atsakymų skaičių, peržiūrų skaičių)',
	'ACP_FEED_EXCLUDE_ID'	=> 'Neįtraukti šių forumų',
	'ACP_FEED_EXCLUDE_ID_EXPLAIN'	=> 'Turinys iš šių forumų <strong>nebus įtraukiamas į srautus</strong>. Norėdami imti duomenis iš visų forumų nepasirinkite nei vieno.<br />Laikydami <samp>CTRL</samp> ir paspaudę kairįjį pelės mygtuką galite pasirinkti daugiau nei vieną forumą.',
	'ACP_VC_SETTINGS_EXPLAIN'	=> 'Čia galite pasirinkti ir nustatyti priedus, kurie yra sukurti blokuoti automatizuotus formas užpildančius internetinių šiukšlių (spam) robotus. Dažniausiai šie priedai veikia pateikdami dalyviams <em>CAPTCHA</em>, užduotis, kurias sudėtinga atlikti kompiuteriui.',
	'AVAILABLE_CAPTCHAS'	=> 'Galimi priedai',
	'CAPTCHA_UNAVAILABLE'	=> 'Jūs negalite pasirinkti šio priedo, nes serveris neturi visų būtinų komponentų.',
	'CAPTCHA_GD'	=> 'GD paveikslėlis',
	'CAPTCHA_GD_3D'	=> 'GD 3D paveikslėlis',
	'CAPTCHA_GD_FOREGROUND_NOISE'	=> 'Priešakinio plano triukšmas',
	'CAPTCHA_GD_EXPLAIN'	=> 'Naudoja GD sukurti sudėtingesnį paveikslėlį internetinių šiukšlių robotams.',
	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'Naudojant priešakinio plano triukšmą paveikslėlis bus dar sunkiau perskaityti.',
	'CAPTCHA_GD_X_GRID'	=> 'Fono triukšmo x-ašis',
	'CAPTCHA_GD_X_GRID_EXPLAIN'	=> 'Mažesnė reikšmė padarys paveikslėlį dar sunkiau perskaitomu. Jeigu norite išjungti x-ašies fono triukšmą, įrašykite 0.',
	'CAPTCHA_GD_Y_GRID'	=> 'Fono triukšmo y-ašis',
	'CAPTCHA_GD_Y_GRID_EXPLAIN'	=> 'Mažesnė reikšmė padarys paveikslėlį dar sunkiau perskaitomu. Jeigu norite išjungti y-ašies fono triukšmą, įrašykite 0.',
	'CAPTCHA_GD_WAVE'	=> 'Banguotas triukšmas',
	'CAPTCHA_GD_WAVE_EXPLAIN'	=> 'Šis parametras padaro paveikslėlio triukšmą banguotą.',
	'CAPTCHA_GD_3D_NOISE'	=> 'Pridėti 3D triukšmo objektus',
	'CAPTCHA_GD_3D_NOISE_EXPLAIN'	=> 'Šis parametras ant raidžių prideda papildomų objektų.',
	'CAPTCHA_GD_FONTS'	=> 'Naudoti skirtingą šriftą',
	'CAPTCHA_GD_FONTS_EXPLAIN'	=> 'Šis parametras kontroliuoja kiek skirtingų raidžių šriftų yra naudojama. Jūs galite naudoti tiek standartines tiek naujas pakeistas raidžių formas. Taip pat galite naudoti ir mažasias raides.',
	'CAPTCHA_FONT_DEFAULT'	=> 'Standartinis',
	'CAPTCHA_FONT_NEW'	=> 'Naujos formos',
	'CAPTCHA_FONT_LOWER'	=> 'Taip pat naudoti mažasias raides',
	'CAPTCHA_NO_GD'	=> 'Paprastas paveikslėlis',
	'CAPTCHA_PREVIEW_MSG'	=> 'Ką tik atlikti pakeitimai dar neišsaugoti. Čia matote tik pavyzdį.',
	'CAPTCHA_PREVIEW_EXPLAIN'	=> 'Taip paveikslėlis atrodys naudojant nurodytus nustatymus.',
	'CAPTCHA_SELECT'	=> 'Įdiegti priedai',
	'CAPTCHA_SELECT_EXPLAIN'	=> 'Išsiskleidžiančiame sąraše matomi priedai buvo atpažinti diskusijų programinės įrangos. Pilki įrašai šiuo metu neprieinami ir prieš naudojant gali prireikti juos nustatyti.',
	'CAPTCHA_CONFIGURE'	=> 'Nustatyti priedus',
	'CAPTCHA_CONFIGURE_EXPLAIN'	=> 'Pakeisti pasirinkto priedo nustatymus.',
	'CONFIGURE'	=> 'Nustatyti',
	'CAPTCHA_NO_OPTIONS'	=> 'Šis priedas neturi nustatymų pasirinkimo.',
	'VISUAL_CONFIRM_POST'	=> 'Įjungti apsaugas nuo internetinių šiukšlių robotų svečių pranešimams',
	'VISUAL_CONFIRM_POST_EXPLAIN'	=> 'Reikalauja, kad svečiai prieš kiekvieną savo pranešimą atliktų užduotį skirtą apsaugai nuo internetinių šiukšlių robotų. Tai gelbsti nuo automatizuoto pranešimų rašymo.',
	'VISUAL_CONFIRM_REG'	=> 'Įjungti apsaugas nuo internetinių šiukšlių robotų registracijos metu',
	'VISUAL_CONFIRM_REG_EXPLAIN'	=> 'Reikalauja, kad vartotojai registracijos metu atliktų užduotį skirtą apsaugai nuo internetinių šiukšlių robotų. Tai gelbsti nuo automatizuotų registracijų.',
	'VISUAL_CONFIRM_REFRESH'	=> 'Leisti vartotojams pasirinkti kitą užduotį',
	'VISUAL_CONFIRM_REFRESH_EXPLAIN'	=> 'Leidžia vartotojams paprašyti naujos užduoties, skirtos apsaugai nuo internetinių šiukšlių robotų, jeigu jie negali jos įvykdyti registracijos metu. Kai kurie priedai gali nepalaikyti šio nustatymo.',
	'ACP_COOKIE_SETTINGS_EXPLAIN'	=> 'Šie parametrai aprašo sausainėlių siunčiamų vartotojų naršyklėms duomenis. Daugumoje atvejų tinka standartiniai nustatymai. Tačiau jeigu jums reikia juos pakeisti, darykite tai atsargiai. Neteisingi nustatymai neleis vartotojams prisijungti.',
	'COOKIE_DOMAIN'	=> 'Sausainėlio domenas',
	'COOKIE_NAME'	=> 'Sausainėlio pavadinimas',
	'COOKIE_PATH'	=> 'Katalogas, kuriame galioja sausainėlis',
	'COOKIE_SECURE'	=> 'Saugus sausainėlis',
	'COOKIE_SECURE_EXPLAIN'	=> 'Jeigu jūsų serveris veikia SSL režimu, įjunkite šį parametrą. Tačiau jeigu įjungsite šį parametrą ir jūsų serveris veikia ne SSL režimu, įvyks klaida.',
	'ONLINE_LENGTH'	=> 'Laiko tarpas kai vartotojai vis dar laikomi prisijungusiais',
	'ONLINE_LENGTH_EXPLAIN'	=> 'Minučių skaičius, po kurio neaktyvūs vartotojai nebus rodomi “Dabar prisijungusių” sąraše. Kuo ši reikšmė didesnė, tuo daugiau sistemos resursų reikia minėto sąrašo generavimui.',
	'SESSION_LENGTH'	=> 'Sesijos trukmė',
	'SESSION_LENGTH_EXPLAIN'	=> 'Po tiek sekundžių pasibaigs sesija.',
	'ACP_LOAD_SETTINGS_EXPLAIN'	=> 'Čia galite įjungti arba išjungti tam tikras diskusijų lentos galimybes, kad sumažintumėte sistemos apkrovimą. Daugumoje serverių šių funkcijų išjungti nereikia. Tačiau kai kuriose sistemose ar internetinio turinio talpinimo serveriuose galimybių, kurių nereikia, išjungimas gali išeiti į naudą. Taip pat čia galite nurodyti sistemos apkrovimo ir aktyvių sesijų ribas, po kurių diskusijų lenta bus automatiškai išjungta.',
	'CUSTOM_PROFILE_FIELDS'	=> 'Papildomi aprašymo laukai',
	'LIMIT_LOAD'	=> 'Riboti sistemos apkrovimą',
	'LIMIT_LOAD_EXPLAIN'	=> 'Jeigu sistemos vienos minutės vidutinis apkrovimas yra didesnis nei ši reikšmė, diskusijų lenta bus automatiškai išjungta. 1.0 reiškia, kad vienas procesorius apkrautas ~100%. Tai veikia tik ant serverių, kuriuose įdiegta UNIX tipo operacinė sistema ir tik ten kur informacija prieinama HTTP servisui. Jeigu phpBB negali gauti šios informacijos, reikšmė laukelyje vėl bus nustatyta į 0.',
	'LIMIT_SESSIONS'	=> 'Riboti sesijas',
	'LIMIT_SESSIONS_EXPLAIN'	=> 'Jeigu per vieną minutę sesijų skaičius tampa didesnis nei šis parametras, diskusijų lenta bus automatiškai išjungta. Jeigu nenorite riboti sesijų, įrašykite 0.',
	'LOAD_CPF_MEMBERLIST'	=> 'Leisti stiliams vartotojų sąraše rodyti papildomus aprašo laukus',
	'LOAD_CPF_VIEWPROFILE'	=> 'Rodyti papildomus laukus vartotojo aprašo lange',
	'LOAD_CPF_VIEWTOPIC'	=> 'Rodyti papildomus aprašo laukus temų puslapiuose',
	'LOAD_USER_ACTIVITY'	=> 'Rodyti vartotojų aktyvumą',
	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'Vartotojo apraše ir valdymo pulte rodyti temas/forumus, kuriuose vartotojas aktyviausias. Diskusijose su daugiau nei milijonu pranešimų rekomenduojama išjungti šį nustatymą.',
	'RECOMPILE_STYLES'	=> 'Perkompiliuoti pasenusius stiliaus komponentus',
	'RECOMPILE_STYLES_EXPLAIN'	=> 'Tikrinti ar failų sistemoje yra atnaujintų stiliaus komponentų ir juos perkompiliuoti.',
	'YES_ANON_READ_MARKING'	=> 'Įjungti temų žymėjimą svečiams',
	'YES_ANON_READ_MARKING_EXPLAIN'	=> 'Išsaugo perskaitytų/neskaitytų temų būseną svečiams. Jeigu išjungsite šį parametrą, visi pranešimai svečiams bus rodomi kaip perskaityti.',
	'YES_BIRTHDAYS'	=> 'Įjungti gimtadienių sąrašo rodymą',
	'YES_BIRTHDAYS_EXPLAIN'	=> 'Jeigu išjungsite, gimtadienių sąrašas nebebus rodomas. Šis nustatymas galioja tik tada, jeigu gimtadieniai apskritai įjungti.',
	'YES_JUMPBOX'	=> 'Įjungti išsiskleidžiantį forumų sąrašą pagrindiniame diskusijų puslapyje',
	'YES_MODERATORS'	=> 'Įjungti moderatorių rodymą',
	'YES_ONLINE'	=> 'Įjungti dabar prisijungusių vartotojų sąrašo rodymą',
	'YES_ONLINE_EXPLAIN'	=> 'Parodo dabar prisijungusių vartotojų duomenis pagrindiniame, forumų ir temų puslapiuose.',
	'YES_ONLINE_GUESTS'	=> 'Įjungti svečių rodymą dabar prisijungusių vartotojų sąraše',
	'YES_ONLINE_GUESTS_EXPLAIN'	=> 'Parodo informaciją apie svečius dabar prisijungusių vartotojų sąraše.',
	'YES_ONLINE_TRACK'	=> 'Rodyti ar vartotojas prisijungęs/atsijungęs',
	'YES_ONLINE_TRACK_EXPLAIN'	=> 'Parodo ar vartotojas prisijungęs vartotojo aprašo bei temų puslapiuose.',
	'YES_POST_MARKING'	=> 'Įjungti temas su žvaigždute',
	'YES_POST_MARKING_EXPLAIN'	=> 'Nurodo ar vartotojas rašė temoje.',
	'YES_READ_MARKING'	=> 'Įjungti temų žymėjimą serverio pusėje',
	'YES_READ_MARKING_EXPLAIN'	=> 'Saugo perskaitytų/neperskaitytų būseną duomenų bazėje, o ne sausainėlyje.',
	'YES_UNREAD_SEARCH'	=> 'Įjungti neperskaitytų pranešimų paiešką',
	'ACP_AUTH_SETTINGS_EXPLAIN'	=> 'phpBB turi galimybę naudoti autentifikacijos modulius. Tai apsprendžia, kaip bus autentifikuojami vartotojai kai jie prisijungs prie diskusijų. Standartiškai pateikiami trys moduliai; duomenų bazė, LDAP ir Apache. Ne visi metodai reikalauja užpildyti visus laukus, todėl pildykite juos, tik jeigu jie atitinka pasirinktą modulį.',
	'AUTH_METHOD'	=> 'Pasirinkite autentifikavimo metodą',
	'APACHE_SETUP_BEFORE_USE'	=> 'Prieš perjungdami phpBB į Apache autentifikavimo režimą turite jį sukonfigūruoti. Atsiminkite, kad Apache vartotojo vardas turi būti toks pats kaip ir phpBB vartotojo vardas. Apache tipo autentifikaciją galima naudoti tik su mod_php (ne CGI versija) ir išjungtu safe_mode režimu.',
	'LDAP_DN'	=> 'LDAP bazinis <var>dn</var>',
	'LDAP_DN_EXPLAIN'	=> 'Visiems vartotojams būdingas bazinis vardas, pvz.: <samp>o=Mano kompanija,c=LT</samp>.',
	'LDAP_EMAIL'	=> 'LDAP el. pašto adreso atributas',
	'LDAP_EMAIL_EXPLAIN'	=> 'Norėdami, kad kiekvieno naujo vartotojo el. pašto adresas būtų užpildytas automatiškai, čia įrašykite vartotojo el. pašto adreso atributo (jeigu toks egzistuoja) pavadinimą. Jeigu nieko neįvesite, visų naujų vartotojų el. pašto adresai bus tušti.',
	'LDAP_INCORRECT_USER_PASSWORD'	=> 'Nepavyko prisijungti prie LDAP serverio su nurodytu vartotojo vardu/slaptažodžiu.',
	'LDAP_NO_EMAIL'	=> 'Nurodytas el. pašto adreso atributas neegzistuoja.',
	'LDAP_NO_IDENTITY'	=> 'Nepavyko rasti %s prisijungimo informacijos.',
	'LDAP_PASSWORD'	=> 'LDAP slaptažodis',
	'LDAP_PASSWORD_EXPLAIN'	=> 'Jeigu nieko neįrašysite bus naudojamas anoniminis prisijungimas. Kitais atvejais įrašykite aukščiau nurodyto vartotojo slaptažodį. Active Directory serveriams šis slaptažodis yra būtinas.<br /><em><strong>Dėmesio:</strong> Duomenų bazėje šis slaptažodis bus saugomas neužkoduotas, todėl bus prieinamas visiems, kurie turi teisę skaityti jūsų duomenų bazę ar peržiūrėti šį puslapį.</em>',
	'LDAP_PORT'	=> 'LDAP serverio portas',
	'LDAP_PORT_EXPLAIN'	=> 'Taip pat, jeigu reikia, galite nurodyti LDAP serverio portą. Standartiškai bus naudojamas 389 portas.',
	'LDAP_SERVER'	=> 'LDAP serverio adresas',
	'LDAP_SERVER_EXPLAIN'	=> 'Jeigu bus naudojamas LDAP, čia įrašykite LDAP serverio internetinį vardą arba IP adresą. Taip pat galite nurodyti ir URL tipo adresą, pvz.: ldap://adresas:portas/.',
	'LDAP_UID'	=> 'LDAP <var>uid</var>',
	'LDAP_UID_EXPLAIN'	=> 'Prisijungimo informacijos raktas, pagal kurį bus ieškoma, pvz.: <var>uid</var>, <var>sn</var> ir t.t.',
	'LDAP_USER'	=> 'LDAP vartotojo <var>dn</var>',
	'LDAP_USER_EXPLAIN'	=> 'Jeigu nieko neįrašysite bus naudojamas anoniminis prisijungimas. Priešingu atveju prisijungimo metu phpBB šio parametro pagalba pabandys rasti teisingą vartotojo vardą, pvz.: <samp>uid=VartotojoVardas,ou=ManoDepartamentas,o=ManoKompanija,c=LT</samp>. Active Directory serveriams šis nustatymas yra būtinas.',
	'LDAP_USER_FILTER'	=> 'LDAP vartotojų filtras',
	'LDAP_USER_FILTER_EXPLAIN'	=> 'Taip pat galite naudoti papildomą filtrą. Pavyzdžiui įrašius <samp>objectClass=posixGroup</samp> bus naudojamas <samp>(&amp;(uid=$username)(objectClass=posixGroup))</samp> filtras.',
	'ACP_SERVER_SETTINGS_EXPLAIN'	=> 'Čia galite keisti serverio ir domeno nustatymus. Įsitikinkite, kad duomenys, kuriuos įrašote, yra tikslūs, kitaip el. laiškuose bus klaidų. Domeno laukelyje nepamirškite įrašyti http:// ar kito protokolo. Serverio portą keiskite tik jeigu tikrai žinote, jog jūsų serveris naudoja kitą portą. Daugumoje atvejų 80 yra teisinga reikšmė.',
	'ENABLE_GZIP'	=> 'Įjungti GZip suspaudimą',
	'ENABLE_GZIP_EXPLAIN'	=> 'Sugeneruotas turinys prieš siunčiant vartotojui bus suspaudžiamas. Tai sumažins tinklo srautą bet padidins tiek serverio tiek kliento kompiuterio apkrovimą. Serveryje turi būti įdiegtas zlib PHP išplėtimas.',
	'FORCE_SERVER_VARS'	=> 'Įjungti šiuos URL nustatymus',
	'FORCE_SERVER_VARS_EXPLAIN'	=> 'Jeigu įjungsite, vietoj automatiškai nustatytų reikšmių bus naudojamos reikšmės iš laukų žemiau.',
	'ICONS_PATH'	=> 'Pranešimų piktogramų saugojimo kelias',
	'ICONS_PATH_EXPLAIN'	=> 'Kelias nuo jūsų pagrindinio phpBB katalogo, pvz.: <samp>images/icons</samp>.',
	'PATH_SETTINGS'	=> 'Katalogų nustatymai',
	'RANKS_PATH'	=> 'Rangų paveikslėlių saugojimo kelias',
	'RANKS_PATH_EXPLAIN'	=> 'Kelias nuo jūsų pagrindinio phpBB katalogo, pvz.: <samp>images/ranks</samp>.',
	'SCRIPT_PATH'	=> 'Kelias iki skriptų',
	'SCRIPT_PATH_EXPLAIN'	=> 'Kelias nuo domeno iki katalogo, kur saugoma phpBB, pvz.: <samp>/phpBB3</samp>.',
	'SERVER_NAME'	=> 'Domenas',
	'SERVER_NAME_EXPLAIN'	=> 'Domeno pavadinimas, po kuriuo veikia šios diskusijos (pavyzdžiui: <samp>www.example.com</samp>).',
	'SERVER_PORT'	=> 'Serverio portas',
	'SERVER_PORT_EXPLAIN'	=> 'Portas, kurio veikia jūsų serveris, dažniausiai 80, keiskite tik esant būtinybei.',
	'SERVER_PROTOCOL'	=> 'Serverio protokolas',
	'SERVER_PROTOCOL_EXPLAIN'	=> 'Serverio protokolas, kuris bus naudojamas, jeigu įjungsite šiuos nustatymus. Jeigu paliksite tuščią arba išjungsite nustatymus, protokolas bus apsprendžiamas pagal saugaus sausainėlių parametrą (<samp>http://</samp> arba <samp>https://</samp>).',
	'SERVER_URL_SETTINGS'	=> 'Serverio URL nustatymai',
	'SMILIES_PATH'	=> 'Šypsenėlių saugojimo kelias',
	'SMILIES_PATH_EXPLAIN'	=> 'Kelias nuo jūsų pagrindinio phpBB katalogo, pvz.: <samp>images/smilies</samp>.',
	'UPLOAD_ICONS_PATH'	=> 'Išplėtimų grupių piktogramų saugojimo kelias',
	'UPLOAD_ICONS_PATH_EXPLAIN'	=> 'Kelias nuo jūsų pagrindinio phpBB katalogo, pvz.: <samp>images/upload_icons</samp>.',
	'ACP_SECURITY_SETTINGS_EXPLAIN'	=> 'Čia galite keisti sesijos ir su prisijungimu susijusius nustatymus.',
	'ALL'	=> 'Visas',
	'ALLOW_AUTOLOGIN'	=> 'Leisti pastovius prisijungimus',
	'ALLOW_AUTOLOGIN_EXPLAIN'	=> 'Nustato, ar leisti vartotojams automatiškai prisijungti.',
	'AUTOLOGIN_LENGTH'	=> 'Pastovaus prisijungimo rakto galiojimo trukmė (dienomis)',
	'AUTOLOGIN_LENGTH_EXPLAIN'	=> 'Dienų skaičius po kurio pastovaus prisijungimo raktas bus ištrintas. Jeigu norite išjungti šį parametrą, įrašykite 0.',
	'BROWSER_VALID'	=> 'Tikrinti naršyklę',
	'BROWSER_VALID_EXPLAIN'	=> 'Kiekvienos sesijos metu bus patikrina vartotojo naršyklė. Taip didinamas saugumas.',
	'CHECK_DNSBL'	=> 'Patikrinti ar IP adresas nėra juodajame DNS sąraše',
	'CHECK_DNSBL_EXPLAIN'	=> 'Jeigu įjungsite šį nustatymą, registracijos metu ir prieš kiekvieną pranešimą vartotojo IP adresas bus patikrintas šiose DNSBL tarnybose: <a href="http://spamcop.net">spamcop.net</a> ir <a href="http://www.spamhaus.org">www.spamhaus.org</a>. Priklausomai nuo jūsų serverio konfigūracijos tai gali užtrukti. Jeigu jaučiate sulėtėjimą arba aptinkama per daug netikrų blogų adresų, rekomenduojama išjungti šį patikrinimą.',
	'CLASS_B'	=> 'A.B',
	'CLASS_C'	=> 'A.B.C',
	'EMAIL_CHECK_MX'	=> 'Patikrinti ar el. pašto adreso domenas turi teisingą MX įrašą',
	'EMAIL_CHECK_MX_EXPLAIN'	=> 'Jeigu įjungsite šį nustatymą, bus patikrinta, ar el. pašto adreso domenas įrašytas registracijos arba aprašymo keitimo metu, turi teisingą MX įrašą.',
	'FORCE_PASS_CHANGE'	=> 'Priversti pasikeisti slaptažodį',
	'FORCE_PASS_CHANGE_EXPLAIN'	=> 'Po nustatyto dienų skaičiaus vartotojas turės pasikeisti savo slaptažodį. Jeigu nenorite versti vartotojų keisti slaptažodžius, įrašykite 0.',
	'FORM_TIME_MAX'	=> 'Maksimalus formos užpildymo laikas',
	'FORM_TIME_MAX_EXPLAIN'	=> 'Kiek laiko vartotojas gali pildyti formą. Jeigu norite neriboti laiko, įrašykite -1. Taip pat atsiminkite, kad vartotojai negalės užpildyti formos ir tuo atveju, jeigu pasibaigė sesijos laikas.',
	'FORM_SID_GUESTS'	=> 'Susieti formas su svečių sesijomis',
	'FORM_SID_GUESTS_EXPLAIN'	=> 'Jeigu įjungsite šį nustatymą formos bus susietos su svečio sesija. Naudojantis kai kuriais Interneto paslaugų teikėjais tai gali sukelti problemų.',
	'FORWARDED_FOR_VALID'	=> 'Patikrinti <var>X_FORWARDED_FOR</var> antraštę',
	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'Sesija bus tęsiama tik tuo atveju, jeigu gauta <var>X_FORWARDED_FOR</var> antraštė sutaps su antrašte gauta praeito kreipimosi į serverį metu. Tai pat <var>X_FORWARDED_FOR</var> antraštė bus patikrinta blokuojamų IP adresų sąraše.',
	'IP_VALID'	=> 'Sesijos IP adreso patikrinimas',
	'IP_VALID_EXPLAIN'	=> 'Nurodo, kokia IP adreso dalis bus naudojama sesijos patikrinimui; <samp>Visas</samp> tikrina visą adresą, <samp>A.B.C</samp> pirmus x.x.x, <samp>A.B</samp> pirmus x.x, <samp>Išjungti</samp> išjungia patikrinimą. IPv6 adreso atveju <samp>A.B.C</samp> reiškia pirmus 4 blokus, o <samp>A.B</samp> pirmus 3 blokus.',
	'IP_LOGIN_LIMIT_MAX'	=> 'Maksimalus nepavykusių prisijungimų skaičius vienam IP adresui',
	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'Nepavykusių prisijungimų skaičius vienam IP adresui, po kurio vartotojas turės išspręsti užduotį, skirtą apsaugai nuo internetinių šiukšlių robotų. Jeigu nenorite, kad apsauga būtų įjungiama atsižvelgiant į IP adresą, įrašykite 0.',
	'IP_LOGIN_LIMIT_TIME'	=> 'IP adreso nepavykusių prisijungimų skaičiaus galiojimo laikas',
	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'Po šio periodo, nepavykusių prisijungimų skaičius skaičiuojamas iš naujo.',
	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'Riboti nepavykusių prisijungimų skaičių pagal <var>X_FORWARDED_FOR</var> antraštę',
	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'Vietoj nepavykysių prisijungimų skaičiavimo pagal IP adresą galite riboti pagal <var>X_FORWARDED_FOR</var> reikšmes. <br /><em><strong>Dėmesio:</strong> Įjunkite tik tuo atveju, jeigu naudojate proksi serverį, kuris nurodo teisingas <var>X_FORWARDED_FOR</var> reikšmes.</em>',
	'MAX_LOGIN_ATTEMPTS'	=> 'Maksimalus nepavykusių prisijungimų skaičius vartotojo vardui',
	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'Nepavykusių prisijungimų skaičius vienam vartotojo vardui, po kurio vartotojas turės išspręsti užduotį, skirtą apsaugai nuo internetinių šiukšlių robotų.',
	'NO_IP_VALIDATION'	=> 'Išjungti',
	'NO_REF_VALIDATION'	=> 'Išjungti',
	'PASSWORD_TYPE'	=> 'Slaptažodžio sudėtingumas',
	'PASSWORD_TYPE_EXPLAIN'	=> 'Nurodo kokio sudėtingumo turi būti įrašomas arba keičiamas slaptažodis. Kiekviena tolesnė reikšmė įtraukia ir prieš tai buvusias.',
	'PASS_TYPE_ALPHA'	=> 'Turi būti iš raidžių ir skaičių',
	'PASS_TYPE_ANY'	=> 'Bet koks',
	'PASS_TYPE_CASE'	=> 'Turi būti iš mažųjų ir didžiųjų raidžių',
	'PASS_TYPE_SYMBOL'	=> 'Turi būti bent vienas specialus simbolis',
	'REF_HOST'	=> 'Tikrinti tik internetinį vardą',
	'REF_PATH'	=> 'Tikrinti ir kelią',
	'REFERER_VALID'	=> 'Tikrinti šaltinį',
	'REFERER_VALID_EXPLAIN'	=> 'Jeigu šis parametras įjungtas, POST užklausų šaltinis (referer) bus patikrintas su internetinio vardo/kelio nustatymais. Jeigu diskusijų lenta naudoja kelis internetinius vardus ir/arba išorinius prisijungimo mechanizmus, tai gali sukelti problemų.',
	'TPL_ALLOW_PHP'	=> 'Leisti php kalbą šablonuose',
	'TPL_ALLOW_PHP_EXPLAIN'	=> 'Jeigu įjungsite šį nustatymą, šablonuose bus atpažinti ir apdoroti <code>PHP</code> ir <code>INCLUDEPHP</code> sakiniai.',
	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'Šie duomenys bus naudojami el. laiškų vartotojams siuntimo metu. Įsitikinkite kad nurodytas el. pašto adresas yra teisingas, kadangi visi nepristatyti laiškai keliaus būtent į šią pašto dėžutę. Jeigu jūsų serveris neteikia arba draudžia el. pašto siuntimą PHP pagalba, galite naudoti SMTP. Tokiu atveju turėsite įrašyti serverio adresą (jeigu reikia, pasiklauskite savo paslaugų teikėjo). Jeigu reikia autentifikuotis į serverį (ir tik tada jeigu reikia), įrašykite reikalingą vartotojo vardą ir slaptažodį. Šiuo metu yra galimybė autentifikuotis tik paprastuoju būdu.',
	'ADMIN_EMAIL'	=> 'Atgalinis el. pašto adresas',
	'ADMIN_EMAIL_EXPLAIN'	=> 'Šis adresas bus naudojamas kaip atgalinis adresas visiems el. laiškams (techninio asmens kontaktas). Jis visada bus naudojamas <samp>Return-Path</samp> ir <samp>Sender</samp> antraštėse.',
	'BOARD_EMAIL_FORM'	=> 'Vartotojai siunčia el. laiškus diskusijų lentos pagalba',
	'BOARD_EMAIL_FORM_EXPLAIN'	=> 'Vietoj kiekvieno vartotojo el. pašto adreso rodymo, vartotojai galės išsiųsti laiškus diskusijų lentos pagalba.',
	'BOARD_HIDE_EMAILS'	=> 'Paslėpti el. pašto adresus',
	'BOARD_HIDE_EMAILS_EXPLAIN'	=> 'Ši galimybė visiškai paslepia el. pašto adresus.',
	'CONTACT_EMAIL'	=> 'Kontaktinis el. pašto adresas',
	'CONTACT_EMAIL_EXPLAIN'	=> 'Šis adresas bus naudojamas ten, kur reikia kontaktinio asmens, pvz.: dėl internetinių šiukšlių (spam), klaidų, ir t.t. Jis visada bus naudojamas <samp>From</samp> ir <samp>Reply-To</samp> antraštėse.',
	'EMAIL_FUNCTION_NAME'	=> 'El. pašto funkcijos pavadinimas',
	'EMAIL_FUNCTION_NAME_EXPLAIN'	=> 'El. pašto siuntimo PHP funkcijos pavadinimas.',
	'EMAIL_PACKAGE_SIZE'	=> 'El. pašto paketo dydis',
	'EMAIL_PACKAGE_SIZE_EXPLAIN'	=> 'Maksimalus laiškų, siunčiamų vienu metu, skaičius. Šis nustatymas galioja vidinei el. pašto eilei. Jeigu turite problemų dėl nepristatytų el. laiškų, įrašykite 0.',
	'EMAIL_SIG'	=> 'El. laiško parašas',
	'EMAIL_SIG_EXPLAIN'	=> 'Šis tekstas bus prikabinamas prie visų laiškų išsiųstų diskusijų lentos pagalba.',
	'ENABLE_EMAIL'	=> 'Įjungti el. pašto funkcijas diskusijose',
	'ENABLE_EMAIL_EXPLAIN'	=> 'Jeigu šis parametras išjungtas, el. pašto funkcionalumas diskusijose bus visiškai išjungtas. <em>Atsiminkite, kad jeigu įjungtas vartotojo arba administratoriaus vardo patvirtinimas, šis nustatymas turi būti įjungtas. Jeigu šiuo metu vartotojo vardo aktyvavimas nustatytas kaip “vartotojas” arba “administratorius”, išjungus šį nustatymą, aktyvacijos nebereikės.</em>',
	'SMTP_AUTH_METHOD'	=> 'SMTP autentifikacijos metodas',
	'SMTP_AUTH_METHOD_EXPLAIN'	=> 'Naudojamas tik jeigu įrašytas vartotojo vardas/slaptažodis. Jeigu neįsitikinę, kurį metodą naudoti, pasiklauskite savo paslaugų teikėjo.',
	'SMTP_CRAM_MD5'	=> 'CRAM-MD5',
	'SMTP_DIGEST_MD5'	=> 'DIGEST-MD5',
	'SMTP_LOGIN'	=> 'LOGIN',
	'SMTP_PASSWORD'	=> 'SMTP slaptažodis',
	'SMTP_PASSWORD_EXPLAIN'	=> 'Įrašykite slaptažodį tik tada, jeigu jūsų SMTP serveriui jis būtinas.<br /><em><strong>Dėmesio:</strong> Duomenų bazėje šis slaptažodis bus saugomas neužkoduotas, todėl bus prieinamas visiems, kurie turi teisę skaityti jūsų duomenų bazę ar peržiūrėti šį puslapį.</em>',
	'SMTP_PLAIN'	=> 'PLAIN',
	'SMTP_POP_BEFORE_SMTP'	=> 'POP-BEFORE-SMTP',
	'SMTP_PORT'	=> 'SMTP serverio portas',
	'SMTP_PORT_EXPLAIN'	=> 'Keiskite tik tada, jeigu žinote, jog jūsų SMTP serveris naudoja kitą portą.',
	'SMTP_SERVER'	=> 'SMTP serverio adresas',
	'SMTP_SETTINGS'	=> 'SMTP nustatymai',
	'SMTP_USERNAME'	=> 'SMTP vartotojo vardas',
	'SMTP_USERNAME_EXPLAIN'	=> 'Įrašykite vartotojo vardą tik tada, jeigu jūsų SMTP serveriui jis būtinas.',
	'USE_SMTP'	=> 'El. paštui naudoti SMTP serverį',
	'USE_SMTP_EXPLAIN'	=> 'Pasirinkite “Taip” jeigu norite ar turite el. paštą siųsti per tam tikrą serverį, o ne vietinę pašto PHP funkciją.',
	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'Čia galite įjungti ir valdyti Jabber protokolą ir greitąsias žinutes. Jabber yra atviras protokolas, kurį gali naudoti visi. Kai kurie Jabber serveriai turi šliuzus, kurių pagalba galite susisiekti su vartotojais iš kitų tinklų. Ne visi serveriai turi galimybę susisiekti su visais tinklais, be to protokolų atnaujinimai gali pakenkti ryšiams tarp tokių tinklų. Įsitikinkite, kad įrašėte teisingą Jabber vartotojo vardą - phpBB netikrins jo tikrumo!',
	'JAB_ENABLE'	=> 'Įjungti Jabber',
	'JAB_ENABLE_EXPLAIN'	=> 'Įjungia Jabber žinutes ir pranešimus.',
	'JAB_GTALK_NOTE'	=> 'Atsiminkite, kad GTalk neveiks, nes nerasta <samp>dns_get_record</samp> funkcija. Šios funkcijos nėra PHP 4 versijoje, ir ji nėra prieinama Windows platformai. Taip pat kol kas ji neveikia BSD sistemose, įskaitant ir Mac OS.',
	'JAB_PACKAGE_SIZE'	=> 'Jabber paketo dydis',
	'JAB_PACKAGE_SIZE_EXPLAIN'	=> 'Žinučių siunčiamų vienu metu skaičius. Jeigu norite visas žinutes išsiųsti iš karto ir nestatyti jų į eilę, įrašykite 0.',
	'JAB_PASSWORD'	=> 'Jabber slaptažodis',
	'JAB_PASSWORD_EXPLAIN'	=> '<em><strong>Dėmesio:</strong> Duomenų bazėje šis slaptažodis bus saugomas neužkoduotas, todėl bus prieinamas visiems, kurie turi teisę skaityti jūsų duomenų bazę ar peržiūrėti šį puslapį.</em>',
	'JAB_PORT'	=> 'Jabber portas',
	'JAB_PORT_EXPLAIN'	=> 'Palikite tuščią, nebent tikrai žinote kad tai ne 5222 portas.',
	'JAB_SERVER'	=> 'Jabber serveris',
	'JAB_SERVER_EXPLAIN'	=> 'Serverių sąrašą rasite %sjabber.org%s puslapyje.',
	'JAB_SETTINGS_CHANGED'	=> 'Jabber nustatymai pakeisti sėkmingai.',
	'JAB_USE_SSL'	=> 'Naudoti saugų prisijungimą',
	'JAB_USE_SSL_EXPLAIN'	=> 'Jeigu įjungsite šį nustatymą, phpBB prie Jabber serverių bandys prisijungti naudodama saugų prisijungimo būdą. Vietoj 5222 bus naudojamas 5223 Jabber portas.',
	'JAB_USERNAME'	=> 'Jabber vartotojo vardas arba JID',
	'JAB_USERNAME_EXPLAIN'	=> 'Nurodykite registruotą vartotojo vardą arba teisingą JID. Vartotojo vardo tikrumas nebus patikrintas. Jeigu nurodysite tik vartotojo vardą, jūsų JID bus sudarytas iš vartotojo vardo ir serverio nurodyto aukščiau. Kitu atveju nurodykite teisingą JID, pavyzdžiui: vartotojas@jabber.org.',
));

?>